@@ -28,9 +28,13 @@ fn main() {
     std::env::set_var("RUST_LOG", "trace");
     env_logger::init();
 
-    // also works in no_std environment
+    // also works in no_std environment (except the println!, of course)
     let archive = include_bytes!("../tests/gnu_tar_default.tar");
     let archive = TarArchive::new(archive);
+    // Vec needs an allocator of course, but the library itself doesn't need one
     let entries = archive.entries().collect::<Vec<_>>();
     println!("{:#?}", entries);
+    println!("content of last file:");
+    let last_file_content = unsafe { core::str::from_utf8_unchecked(entries[2].data()) };
+    println!("{:#?}", last_file_content);
 }
